@@ -10,10 +10,13 @@ system_platform = sys.platform
 main_path = '/home/pi/class/'  # 读取和保存文件所用主文件夹
 if 'win' in system_platform:
     # 获取当前文件的位置
-    file_path = os.path.join(os.getcwd().split('blockly-electron')[0],'blockly-electron')
-    main_path = file_path + '\\resources\\assets\\class\\'
-picture_path = main_path + 'picture/'  # 图片文件夹
-model_path = main_path + 'model/'  # 识别模型文件夹
+    file_path = os.path.join(os.getcwd().split('blockly-electron')[0], 'blockly-electron')
+    if not os.path.exists(file_path):
+        if os.path.exists(os.path.join(os.getcwd(), "resources")):
+            file_path = os.getcwd()
+    main_path = os.path.join(file_path, 'resources', 'assets', 'class').replace("\\", "/")
+picture_path = os.path.join(main_path , 'picture/')  # 图片文件夹
+model_path = os.path.join(main_path , 'model/')  # 识别模型文件夹
 #查找文件夹下存在的pkl模型的名字（没有pkl后缀）
 def findExisModel():
     '''
@@ -21,6 +24,7 @@ def findExisModel():
     Returns:
 
     '''
+    print(model_path)
     if os.path.exists(model_path):
         return [model_name[:-4] for model_name in os.listdir(model_path) if
                                   model_name.endswith(".pkl")]  # model文件夹下面存在的pkl模型文件名的列表
