@@ -56,6 +56,30 @@ def new_file(path:str):
         print('未找到该文件夹。开始创建文件夹')
         os.makedirs(path)
 
+        
+def zeros_like(img:np.ndarray):
+    '''
+    创建一个与img图像等尺寸的全零图像
+    Args:
+        img: 输入图像
+
+    Returns:输出全零图像
+
+    '''
+    return np.zeros_like(img)
+
+def line(img:np.ndarray,point1:tuple,point2:tuple):
+    '''
+    在图片的某两点之间画线
+    Args:
+        img: 
+        point1: 
+        point2: 
+
+    Returns:
+
+    '''
+    cv2.line(img, point1, point2, (255, 0, 0))
 
 class Img(basicImg,AdvancedImg):
     '''
@@ -773,7 +797,7 @@ class Img(basicImg,AdvancedImg):
         mask = cv2.erode(mask, None, iterations=2)
         # 膨胀操作，其实先腐蚀再膨胀的效果是开运算，去除噪点
         self.mask_img = cv2.dilate(mask, None, iterations=2)
-        self.mask_img = cv2.resize(self.img, dsize= (640,480) )  # 这一行是放大图像变回 640✖480
+        self.mask_img = cv2.resize(self.mask_img, dsize= (640,480) )  # 这一行是放大图像变回 640✖480
         cv2.imshow('mask', self.mask_img)
         cv2.waitKey(3)
 
@@ -962,7 +986,7 @@ class Img(basicImg,AdvancedImg):
 
         '''
         if not bool(self.fingertip):
-            return '没有检测到手指'
+            return -1
         if tip2 == tip1:
             return 0
         else:
@@ -1029,7 +1053,7 @@ class Img(basicImg,AdvancedImg):
 
         '''
         if not bool(self.body_menu):
-            return '-1'
+            return -1
         if wrist1 == wrist2:
             return 0
         return math.pow(math.pow(self.body_menu[wrist1][0] - self.body_menu[wrist2][0], 2) + math.pow(
